@@ -33,6 +33,7 @@ typedef struct
     u32 length;
     u32 stop;
     u32 fade;
+    u32 volume;
     char *title;
     char *artist;
     char *game;
@@ -95,4 +96,9 @@ int upse_has_custom_bios(void);
 const char *upse_get_custom_bios(void);
 void upse_set_custom_bios(const char *bios);
 
+/*
+ * Utility functions.
+ */
+float upse_strtof(const char *value);
+
 #endif
