@@ -18,7 +18,6 @@
 
 #define _IN_SPU
 
-
 #include "upse-types.h"
 #include "upse-internal.h"
 #include "upse-ps1-spu-base.h"
@@ -247,8 +246,10 @@ static u32 decaybegin;
 static u32 decayend;
 
 // Counting to 65536 results in full volume offage.
-void SPUsetlength(s32 stop, s32 fade)
+void upse_ps1_spu_setlength(s32 stop, s32 fade)
 {
+    _ENTER;
+
     if (stop == ~0)
     {
 	decaybegin = ~0;
@@ -261,6 +262,22 @@ void SPUsetlength(s32 stop, s32 fade)
 	decaybegin = stop;
 	decayend = stop + fade;
     }
+
+    _LEAVE;
+}
+
+void upse_ps1_spu_setvolume(int volume)
+{
+    _ENTER;
+
+    if (volume >= 32)
+        iVolume = 0;
+    else
+        iVolume = (volume / 4);
+
+    _DEBUG("new volume [%d] [%d]", iVolume, volume);
+
+    _LEAVE;
 }
 
 static u32 seektime;
@@ -277,9 +294,8 @@ static u32 _do_interpolation = 1;
 static double _interpolation_coefficient = 3.759285613;
 
 #define CLIP(_x) {if(_x>32767) _x=32767; if(_x<-32767) _x=-32767;}
-int SPUasync(u32 cycles)
+int upse_ps1_spu_render(u32 cycles)
 {
-    int volmul = iVolume;
     static s32 dosampies;
     s32 temp;
 
@@ -571,8 +587,8 @@ int SPUasync(u32 cycles)
 	}
 
 	/* fix dynamic range. */
-	sl = (sl * volmul) >> 10;
-	sr = (sr * volmul) >> 10;
+	sl >>= iVolume;
+	sr >>= iVolume;
 
 	if (sl > 32767)
 	    sl = 32767;
@@ -629,7 +645,7 @@ void upse_set_interpolation_coefficient(double setting)
     _LEAVE;
 }
 
-void SPUendflush(void)
+void upse_ps1_spu_finalize(void)
 {
     if ((seektime != (u32) ~ 0) && seektime > sampcount)
     {
@@ -669,7 +685,7 @@ static u64 SexyTime64(void)
 // SPUINIT: this func will be called first by the main emu
 ////////////////////////////////////////////////////////////////////////
 
-int SPUinit(void)
+int upse_ps1_spu_init(void)
 {
     spuMemC = (u8 *) spuMem;	// just small setup
     memset((void *) s_chan, 0, MAXCHAN * sizeof(SPUCHAN));
@@ -732,7 +748,7 @@ void RemoveStreams(void)
 // SPUOPEN: called by main emu after init
 ////////////////////////////////////////////////////////////////////////
 
-int SPUopen(void)
+int upse_ps1_spu_open(void)
 {
     if (bSPUIsOpen)
 	return 0;		// security for some stupid main emus
@@ -746,7 +762,7 @@ int SPUopen(void)
     memset((void *) s_chan, 0, (MAXCHAN + 1) * sizeof(SPUCHAN));
     pSpuIrq = 0;
 
-    iVolume = 160;		//85;
+    iVolume = 0;		// full volume (0dB), volume past this point is seen as a pad, where 8 = -64dB
     SetupStreams();		// prepare streaming
 
     bSPUIsOpen = 1;
@@ -760,7 +776,7 @@ int SPUopen(void)
 // SPUCLOSE: called before shutdown
 ////////////////////////////////////////////////////////////////////////
 
-int SPUclose(void)
+int upse_ps1_spu_close(void)
 {
     if (!bSPUIsOpen)
 	return 0;		// some security
