@@ -15,6 +15,8 @@
  * UPSE is offered without any warranty of any kind, explicit or implicit.
  */
 
+#define _ISOC99_SOURCE
+
 #include <stdio.h>
 #include <string.h>
 #include <stdlib.h>
@@ -24,7 +26,8 @@
 #include "upse.h"
 #include "upse-string.h"
 
-void upse_execute(void)
+void
+upse_execute(void)
 {
     _ENTER;
 
@@ -32,3 +35,17 @@ void upse_execute(void)
 
     _LEAVE;
 }
+
+float
+upse_strtof(const char *value)
+{
+    float val;
+
+    _ENTER;
+
+    val = strtof(value, NULL);
+
+    _LEAVE;
+
+    return val;
+}
